# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This Source Code Form is "Incompatible With Secondary Licenses", as
# defined by the Mozilla Public License, v. 2.0.

package Bugzilla::Extension::ActivityReport::WebService;

use strict;
use warnings;
use 5.10.1;

use base qw(Bugzilla::WebService);
use Bugzilla::Constants;
use Bugzilla::Error;
use Bugzilla::WebService::Util qw(validate);

use Bugzilla::Extension::ActivityReport::Reports qw(user_activity_report);

use constant PUBLIC_METHODS => qw(
  user_activity
);

sub user_activity {
  my ($self, $params) = validate(@_);

  my $user = Bugzilla->login(LOGIN_REQUIRED);

  my $ips;
  $ips->{who} = $params->{who};

  ThrowCodeError('param_required',
    {function => 'ActivityReport.user_activity', param => 'who'})
    unless ($ips->{who} && $ips->{who} ne '');

  $ips->{from} = $params->{from} if ($params->{from});
  $ips->{to}   = $params->{to}   if ($params->{to});
  $ips->{sort} = $params->{sort} if ($params->{sort});
  $ips->{action} = 'run';

  Bugzilla->input_params($ips);

  my %vars;
  user_activity_report(\%vars);

  # delete internal vars
  delete($vars{action});
  delete($vars{incomplete_data});

  return (\%vars);
}

1;

__END__

=head1 NAME

Bugzilla::Extension::ActivityReport::WebService - The API for accessing Activity Reports.

=head1 DESCRIPTION

This API allows you to access some of the Activity Reports.

=head1 METHODS

=over

=item C<user_activity>

    Description: Show changes made by an individual user.
    Params:
                who: Comma separate list of users to report on.
                from: Date to start report. * Optional.
                to: date to end report. * Optional.
                sort: How to sort report. when or bug. * Optional.

    Returns: A hash with the following keys:
        from: The date the reports starts.
        to:   The date the report ends.
        who:  The list of users included in the report.
        who_count: The number of users icovered in the report.
        operations: An array of the actions performed.
        sort: The order the operations are sorted.

=back

