# -*- Mode: perl; indent-tabs-mode: nil -*-
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# Copyright (C) 2013 Jolla Ltd.
# Contact: Pami Ketolainen <pami.ketolainen@jollamobile.com>

=head1 NAME

Bugzilla::Extension::AgileTools::Pages::Team

=head1 DESCRIPTION

Team realted page handler functions

=head1 HANDLERS

=over

=cut

use strict;
use warnings;
use 5.10.1;

package Bugzilla::Extension::AgileTools::Pages::Team;

use Bugzilla::Extension::AgileTools::Constants;
use Bugzilla::Extension::AgileTools::Role;
use Bugzilla::Extension::AgileTools::Team;
use Bugzilla::Extension::AgileTools::Util;

use Bugzilla::Constants;
use Bugzilla::Error;

use JSON;

=item C<list> - The "All Teams" page

=cut

sub list {
  my ($vars) = @_;
  my $cgi    = Bugzilla->cgi;
  my $action = $cgi->param("action") || "";
  $vars->{can_manage_teams} = user_can_manage_teams();
  $vars->{can_create_teams}
    = user_can_manage_teams() || user_in_agiletools_group();
  if ($action eq "remove") {
    ThrowUserError("agile_team_manage_denied") unless $vars->{can_manage_teams};
    my $team
      = Bugzilla::Extension::AgileTools::Team->check({
      id => scalar $cgi->param("team_id")
      });
    $vars->{team} = {name => $team->name};
    $team->remove_from_db();
    $vars->{message} = "agile_team_removed";
  }
  $vars->{user_teams} = scalar $cgi->param('user_teams') ? 1 : 0;
  my @teams
    = $vars->{user_teams}
    ? @{Bugzilla->user->agile_teams}
    : $vars->{can_manage_teams} ?
    ## RED HAT EXTENSION START 1323078
    Bugzilla::Extension::AgileTools::Team->get_all()
    : @{Bugzilla->user->visible_agile_teams};
  ## RED HAT EXTENSION END 1323078
  $vars->{active_teams}   = [grep($_->is_active,  @teams)];
  $vars->{inactive_teams} = [grep(!$_->is_active, @teams)];

  return;
}

=item C<show> - Single team view page

=cut

sub show {
  my ($vars) = @_;
  my $user   = Bugzilla->user;
  my $cgi    = Bugzilla->cgi;
  my $team;
  my $action = $cgi->param("action") || "";
  if ($action eq "create") {
    ThrowUserError("agile_team_manage_denied") unless user_in_agiletools_group;

    $team = Bugzilla::Extension::AgileTools::Team->create({
      name       => scalar $cgi->param("name"),
      process_id => scalar $cgi->param("process_id"),
    });
    if ($cgi->param("create_backlog")) {
      Bugzilla::Extension::AgileTools::Backlog->create({
        name => $team->name . " backlog", team_id => $team->id,
      });
    }

    if ($cgi->param("view_groups")) {
      my @groups = $cgi->param("view_groups");
      foreach my $group (@groups) {
        $team->add_view_group(get_group($group));
      }
    }

    if ($cgi->param("edit_groups")) {
      my @groups = $cgi->param("edit_groups");
      foreach my $group (@groups) {
        $team->add_edit_group(get_group($group));
      }
    }
    else {
      $team->add_member(Bugzilla->user);
      my $role = get_role("Scrum Master");
      $role->add_user_role($team, Bugzilla->user);
    }

    $vars->{message} = "agile_team_created";
  }
  elsif ($action eq 'save') {
    my $id = $cgi->param("team_id");
    $team = Bugzilla::Extension::AgileTools::Team->check({id => $id});
    ## RED HAT EXTENSION START 1323078
    ThrowUserError("agile_team_edit_not_allowed", {name => $team->name})
      unless $team->user_can_edit();
    ## RED HAT EXTENSION END 1323078
    $team->set_all({
      name      => scalar $cgi->param('name'),
      is_active => scalar $cgi->param('is_active') ? 1 : 0,
    });
    $vars->{changes} = scalar $team->update();
    $vars->{message} = 'agile_team_saved';
    $vars->{team}    = $team;

  }
  else {
    my $id = $cgi->param("team_id");
    $team = Bugzilla::Extension::AgileTools::Team->check({id => $id});
    ## RED HAT EXTENSION START 1323078
    ThrowUserError("agile_team_view_denied", {name => $team->name})
      unless $team->user_can_view();
    ## RED HAT EXTENSION END 1323078
  }

  $vars->{processes} = AGILE_PROCESS_NAMES;
  $vars->{team}      = $team;
  $vars->{roles}     = Bugzilla::Extension::AgileTools::Role->match();

  $vars->{available_backlogs}
    = Bugzilla::Extension::AgileTools::Backlog->match({team_id => IS_NULL});
  $team->roles;
  $vars->{team_json} = JSON->new->convert_blessed->encode($team);

  ## REDHAT EXTENSION START 1323078
  # share groups with templates
  $vars->{groups} = [Bugzilla::Group->get_all()];
  ## REDHAT EXTENSION END 1323078

  return;
}

=item C<create> - The create team page

=cut

sub create {
  my ($vars) = @_;
  ThrowUserError("agile_team_manage_denied") unless user_in_agiletools_group;
  $vars->{processes} = AGILE_PROCESS_NAMES;

  $vars->{groups} = [Bugzilla::Group->get_all()];

  return;
}

=back

=cut

1;
__END__
