# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::SAML2Auth::Params;

use strict;
use warnings;
use 5.10.1;

use Bugzilla::Config::Common;

sub get_param_list {
  my ($class) = @_;

  return (
    {
      name    => 'saml2auth_sp_crt',
      desc    => 'Full path to crt file used by IDPs to verify requests',
      type    => 't',
      default => '/etc/httpd/conf/ssl.crt',
    },
    {
      name    => 'saml2auth_sp_key',
      desc    => 'Full path to key file used to sign and encrypt requests',
      type    => 't',
      default => '/etc/httpd/conf/ssl.key',
    },
    {
      name    => 'saml2auth_sp_cacert',
      desc    => 'Full path to CA file used to verify certificates',
      type    => 't',
      default => '/etc/pki/tls/certs/ca-bundle.trust.crt',
    },
  );
}

1;

__END__

=head1 Description

Bugzilla::Extension::SAML2Auth::Params - A module for specifying parameters to be added to the data/params.json file.

=head1 Parameters

=over 4

=item saml2auth_sp_crt

Full path to public key crt file, used by IDPs to verify requests.

=item saml2auth_sp_key

Full path to private key file, used to sign and encrypt requests.

=item saml2auth_sp_cacert

Full path to CA file used to verify this SP's certificates.

=back

